package com.muyu.customer.business.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import com.muyu.common.core.annotation.Excel;
import com.muyu.customer.business.domain.req.IndexConfigurationEditReq;
import com.muyu.customer.business.domain.req.IndexConfigurationQueryReq;
import com.muyu.customer.business.domain.req.IndexConfigurationSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;


/**
 * 车辆指标预警配置对象 index_configuration
 *
 * @author muyu
 * @date 2024-06-28
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("index_configuration")
@ApiModel(value = "IndexConfiguration", description = "车辆指标预警配置")
public class IndexConfiguration {

    private static final long serialVersionUID = 1L;

    /** 主键id */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键id", value = "主键id")
    private Long id;

    /** 车辆vin */
    @Excel(name = "车辆vin")
    @ApiModelProperty(name = "车辆vin", value = "车辆vin")
    private String vin;

    /** 指标项key */
    @Excel(name = "指标项key")
    @ApiModelProperty(name = "指标项key", value = "指标项key")
    private String keyCode;

    /** 滑窗范围(秒) */
    @Excel(name = "滑窗范围(秒)")
    @ApiModelProperty(name = "滑窗范围(秒)", value = "滑窗范围(秒)")
    private Long intervalRange;

    /** 滑窗时机(秒) */
    @Excel(name = "滑窗时机(秒)")
    @ApiModelProperty(name = "滑窗时机(秒)", value = "滑窗时机(秒)")
    private Long opportunity;

    /** 类型：1 上升 2 波动 3 下降 */
    @Excel(name = "类型：1 上升 2 波动 3 下降")
    @ApiModelProperty(name = "类型：1 上升 2 波动 3 下降", value = "类型：1 上升 2 波动 3 下降")
    private Long attributeType;

    /** 指标值 */
    @Excel(name = "指标值")
    @ApiModelProperty(name = "指标值", value = "指标值")
    private String attributeValue;

    /**
    * 查询构造器
    */
    public static IndexConfiguration queryBuild( IndexConfigurationQueryReq indexConfigurationQueryReq){
        return IndexConfiguration.builder()
                .vin(indexConfigurationQueryReq.getVin())
                .build();
    }

    /**
    * 添加构造器
    */
    public static IndexConfiguration saveBuild(IndexConfigurationSaveReq indexConfigurationSaveReq){
        return IndexConfiguration.builder()
                .vin(indexConfigurationSaveReq.getVin())
                .keyCode(indexConfigurationSaveReq.getKeyCode())
                .intervalRange(indexConfigurationSaveReq.getIntervalRange())
                .opportunity(indexConfigurationSaveReq.getOpportunity())
                .attributeType(indexConfigurationSaveReq.getAttributeType())
                .attributeValue(indexConfigurationSaveReq.getAttributeValue())
                .build();
    }

    /**
    * 修改构造器
    */
    public static IndexConfiguration editBuild(Long id, IndexConfigurationEditReq indexConfigurationEditReq){
        return IndexConfiguration.builder()
            .id(id)
                .vin(indexConfigurationEditReq.getVin())
                .keyCode(indexConfigurationEditReq.getKeyCode())
                .intervalRange(indexConfigurationEditReq.getIntervalRange())
                .opportunity(indexConfigurationEditReq.getOpportunity())
                .attributeType(indexConfigurationEditReq.getAttributeType())
                .attributeValue(indexConfigurationEditReq.getAttributeValue())
                .build();
    }

}
