package com.muyu.customer.business.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.annotation.Excel;
import com.muyu.customer.business.domain.req.MessageDetailEditReq;
import com.muyu.customer.business.domain.req.MessageDetailQueryReq;
import com.muyu.customer.business.domain.req.MessageDetailSaveReq;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 报文详情对象 message_detail
 *
 * @author muyu
 * @date 2024-06-28
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("message_detail")
@ApiModel(value = "MessageDetail", description = "报文详情")
public class MessageDetail {


    /** 报文id */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "报文id", value = "报文id")
    private Long id;

    /** 数据项key */
    @Excel(name = "数据项key")
    @ApiModelProperty(name = "数据项key", value = "数据项key")
    private String keyCode;

    /** 起始位 */
    @Excel(name = "起始位")
    @ApiModelProperty(name = "起始位", value = "起始位")
    private String startBit;

    /** 结束位 */
    @Excel(name = "结束位")
    @ApiModelProperty(name = "结束位", value = "结束位")
    private String stopBit;

    /** 标签 */
    @Excel(name = "标签")
    @ApiModelProperty(name = "标签", value = "标签")
    private String label;

    /** 类型 */
    @Excel(name = "类型")
    @ApiModelProperty(name = "类型", value = "类型")
    private String type;

//    private String vin;

    /**
    * 查询构造器
    */
    public static MessageDetail queryBuild( MessageDetailQueryReq messageDetailQueryReq){
        return MessageDetail.builder()
                .keyCode(messageDetailQueryReq.getKeyCode())
                .startBit(messageDetailQueryReq.getStartBit())
                .stopBit(messageDetailQueryReq.getStopBit())
                .label(messageDetailQueryReq.getLabel())
                .type(messageDetailQueryReq.getType())
                .build();
    }

    /**
    * 添加构造器
    */
    public static MessageDetail saveBuild(MessageDetailSaveReq messageDetailSaveReq){
        return MessageDetail.builder()
                .keyCode(messageDetailSaveReq.getKeyCode())
                .startBit(messageDetailSaveReq.getStartBit())
                .stopBit(messageDetailSaveReq.getStopBit())
                .label(messageDetailSaveReq.getLabel())
                .type(messageDetailSaveReq.getType())
                .build();
    }

    /**
    * 修改构造器
    */
    public static MessageDetail editBuild(Long id, MessageDetailEditReq messageDetailEditReq){
        return MessageDetail.builder()
            .id(id)
                .keyCode(messageDetailEditReq.getKeyCode())
                .startBit(messageDetailEditReq.getStartBit())
                .stopBit(messageDetailEditReq.getStopBit())
                .label(messageDetailEditReq.getLabel())
                .type(messageDetailEditReq.getType())
                .build();
    }

}
