package com.muyu.customer.business.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.customer.business.domain.Vehicle;
import com.muyu.customer.business.domain.model.MessageDetailModel;
import com.muyu.customer.business.domain.model.VehicleMiddle;
import com.muyu.customer.business.mapper.VehicleMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import com.muyu.customer.business.mapper.MessageDetailMapper;
import com.muyu.customer.business.domain.MessageDetail;
import com.muyu.customer.business.service.MessageDetailService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 报文详情Service业务层处理
 *
 * @author muyu
 * @date 2024-06-28
 */
@Slf4j
@Service
public class MessageDetailServiceImpl extends ServiceImpl<MessageDetailMapper, MessageDetail>  implements MessageDetailService {

    @Autowired
    private MessageDetailMapper messageDetailMapper;
    @Autowired
    private VehicleMapper vehicleMapper;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * 查询报文详情列表
     *
     * @param messageDetail 报文详情
     * @return 报文详情
     */
    @Override
    public List<MessageDetail> list(MessageDetail messageDetail) {
        LambdaQueryWrapper<MessageDetail> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(messageDetail.getKeyCode())){
            queryWrapper.eq(MessageDetail::getKeyCode, messageDetail.getKeyCode());
        }

        if (ObjUtils.notNull(messageDetail.getStartBit())){
            queryWrapper.eq(MessageDetail::getStartBit, messageDetail.getStartBit());
        }

        if (ObjUtils.notNull(messageDetail.getStopBit())){
            queryWrapper.eq(MessageDetail::getStopBit, messageDetail.getStopBit());
        }

        if (ObjUtils.notNull(messageDetail.getLabel())){
            queryWrapper.eq(MessageDetail::getLabel, messageDetail.getLabel());
        }

        if (ObjUtils.notNull(messageDetail.getType())){
            queryWrapper.eq(MessageDetail::getType, messageDetail.getType());
        }
        return list(queryWrapper);
    }

    @Override
    public List<MessageDetail> selectMessage(String vin) {

        Vehicle vehicle=messageDetailMapper.selectByVin(vin);
        List<Integer> vehicleMiddleList=messageDetailMapper.selectByVehicleId(vehicle.getId());
        if (vehicleMiddleList.isEmpty()){
            return null;
        }
        return messageDetailMapper.selectMessage(vehicleMiddleList);
    }

    @Override
    public Result<String> add(MessageDetailModel messageDetailModel) {
        Integer enterpriseId = SecurityUtils.getLoginUser().getSysUser().getEnterpriseId();
        Vehicle vehicle=messageDetailMapper.selectByVin(messageDetailModel.getVin());
        ArrayList<MessageDetail> messageDetails = new ArrayList<>();
        for (Integer s : messageDetailModel.getIds()) {
            vehicleMapper.addMiddle(vehicle.getId(), s);
            MessageDetail messageDetail = vehicleMapper.selectDetail(s);
            messageDetails.add(messageDetail);
        }
        redisTemplate.opsForHash().put(enterpriseId+"", messageDetailModel.getVin(), JSON.toJSONString(messageDetails));
        return Result.success();
    }

    @Override
    public Result<String> updateVehicle(MessageDetailModel messageDetailModel) {
        Integer enterpriseId = SecurityUtils.getLoginUser().getSysUser().getEnterpriseId();
        Vehicle vehicle=messageDetailMapper.selectByVin(messageDetailModel.getVin());
        vehicleMapper.deleteMiddle(vehicle.getId());
        ArrayList<MessageDetail> messageList = new ArrayList<>();
        for (Integer s : messageDetailModel.getIds()) {
            vehicleMapper.addMiddle(vehicle.getId(), s);
            MessageDetail messageDetail = vehicleMapper.selectDetail(s);
            messageList.add(messageDetail);
        }
        redisTemplate.opsForHash().put(enterpriseId+"", messageDetailModel.getVin(), JSON.toJSONString(messageList));
        rabbitTemplate.convertAndSend("eventMonitor",messageDetailModel.getVin()+"_"+enterpriseId);
        return Result.success();
    }
}
