package com.muyu.customer.business.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson.JSON;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.customer.business.domain.MessageDetail;
import com.muyu.customer.business.domain.model.VehicleModel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import com.muyu.customer.business.mapper.VehicleMapper;
import com.muyu.customer.business.domain.Vehicle;
import com.muyu.customer.business.service.VehicleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 车辆录入Service业务层处理
 *
 * @author muyu
 * @date 2024-05-27
 */
@Slf4j
@Service
public class VehicleServiceImpl extends ServiceImpl<VehicleMapper, Vehicle>  implements VehicleService {
    @Autowired
    private VehicleMapper vehicleMapper;

    /**
     * 查询车辆录入列表
     *
     * @param vehicle 车辆录入
     * @return 车辆录入
     */
    @Override
    public List<Vehicle> list(Vehicle vehicle) {
        LambdaQueryWrapper<Vehicle> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(vehicle.getVin())){
            queryWrapper.eq(Vehicle::getVin, vehicle.getVin());
        }

        if (ObjUtils.notNull(vehicle.getBrand())){
            queryWrapper.eq(Vehicle::getBrand, vehicle.getBrand());
        }

        if (ObjUtils.notNull(vehicle.getModel())){
            queryWrapper.eq(Vehicle::getModel, vehicle.getModel());
        }

        if (ObjUtils.notNull(vehicle.getProductionDate())) {
            queryWrapper.eq(Vehicle::getProductionDate, vehicle.getProductionDate());
        }

        if (ObjUtils.notNull(vehicle.getBodyType())) {
            queryWrapper.eq(Vehicle::getBodyType, vehicle.getBodyType());
        }

        if (ObjUtils.notNull(vehicle.getColor())) {
            queryWrapper.eq(Vehicle::getColor, vehicle.getColor());
        }

        if (ObjUtils.notNull(vehicle.getEngineCapacity())) {
            queryWrapper.eq(Vehicle::getEngineCapacity, vehicle.getEngineCapacity());
        }

        if (ObjUtils.notNull(vehicle.getFuelType())) {
            queryWrapper.eq(Vehicle::getFuelType, vehicle.getFuelType());
        }

        if (ObjUtils.notNull(vehicle.getTransmission())) {
            queryWrapper.eq(Vehicle::getTransmission, vehicle.getTransmission());
        }

        if (ObjUtils.notNull(vehicle.getDriveType())) {
            queryWrapper.eq(Vehicle::getDriveType, vehicle.getDriveType());
        }

        if (ObjUtils.notNull(vehicle.getMileage())) {
            queryWrapper.eq(Vehicle::getMileage, vehicle.getMileage());
        }

        if (ObjUtils.notNull(vehicle.getRegistrationDate())) {
            queryWrapper.eq(Vehicle::getRegistrationDate, vehicle.getRegistrationDate());
        }

        if (ObjUtils.notNull(vehicle.getLicenseNumber())) {
            queryWrapper.eq(Vehicle::getLicenseNumber, vehicle.getLicenseNumber());
        }

        if (ObjUtils.notNull(vehicle.getHolder())) {
            queryWrapper.eq(Vehicle::getHolder, vehicle.getHolder());
        }

        if (ObjUtils.notNull(vehicle.getVehicleType())) {
            queryWrapper.eq(Vehicle::getVehicleType, vehicle.getVehicleType());
        }


        return list(queryWrapper);
    }

    @Override
    public List<MessageDetail> MessageList() {
        return vehicleMapper.MessageList();
    }


    @Override
    public String add(VehicleModel vehicleModel) {
        vehicleMapper.add(vehicleModel);

        return "成功";
    }

    @Override
    public VehicleModel selectById(Long id) {
//        List<Integer> vehicleMiddleList= vehicleMapper.selectMessageList(id);
        VehicleModel vehicleModel= vehicleMapper.selectId(id);
//        vehicleModel.setMessageDetail(vehicleMiddleList);
        System.out.println(vehicleModel.getMessageDetail());
        return vehicleModel;
    }

    @Override
    public List<MessageDetail> selectMessage(Long id) {
        return vehicleMapper.selectMessage(id);
    }

    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private RabbitTemplate rabbitTemplate;
    @Override
    public Result updateVehicle(Long id, VehicleModel vehicleModel) {
        int i = vehicleMapper.updateVehicle(id, vehicleModel);
//        vehicleMapper.deleteMiddle(id);
//
//
        return Result.success();
    }

}
